@@ -1,11 +1,11 @@
-#!/usr/local/bin/ruby
+#!/usr/bin/env ruby
 =begin
   anim.rb - Ruby/GdkPixbuf sample script.
 
   Copyright (c) 2002,2003 Ruby-GNOME2 Project Team
   This program is licenced under the same licence as Ruby-GNOME2.
 
-  $Id: anim.rb,v 1.3 2003/01/17 19:20:43 mutoh Exp $
+  $Id: anim.rb,v 1.4 2005/03/22 17:41:24 silicio Exp $
 =end
 
 require 'gtk2'
