@@ -13,11 +13,16 @@ PACKAGE_NAME = "glib2"
 require 'mkmf-gnome2'
 
 PKGConfig.have_package('gobject-2.0') or exit 1
+PKGConfig.have_package('gthread-2.0')
 
 setup_win32(PACKAGE_NAME)
 
 have_func("g_spawn_close_id")
 have_func("g_thread_init")
+have_func("g_main_depth")
+
+have_func("rb_check_array_type")
+have_func("rb_exec_recursive")
 
 create_makefile_at_srcdir(PACKAGE_NAME, SRCDIR, "-DRUBY_GLIB2_COMPILATION")
 
