@@ -6,8 +6,8 @@
   Copyright (C) 2004 Ruby-GNOME2 Project Team
   This program is licenced under the same licence as Ruby-GNOME2.
 
-  $Date: 2005/01/09 07:20:51 $
-  $Id: type-register.rb,v 1.7 2005/01/09 07:20:51 mutoh Exp $
+  $Date: 2005/07/30 11:01:03 $
+  $Id: type-register.rb,v 1.8 2005/07/30 11:01:03 mutoh Exp $
 =end
 
 require 'gtk2'
@@ -101,8 +101,4 @@ p b.get_property("fuga")
 b.set_property("fuga", 1)
 p b.get_property("fuga")
 
-p b.get_property("hoge")
-b.set_property("hoge", ["a", "b", "c"])
-p b.get_property("hoge")
-
 p MyButton2.ancestors
