@@ -4,7 +4,7 @@
   rbglib.c -
 
   $Author: mutoh $
-  $Date: 2005/03/05 06:55:37 $
+  $Date: 2005/06/16 13:27:33 $
 
   Copyright (C) 2002,2003  Masahiro Sakai
 
@@ -26,6 +26,11 @@ extern void Init_glib_spawn();
 extern void Init_glib_fileutils();
 extern void Init_glib_utils();
 extern void Init_gobject();
+extern void Init_glib_main_loop();
+extern void Init_glib_main_context();
+extern void Init_glib_source();
+extern void Init_glib_poll_fd();
+extern void Init_glib_io_channel();
 
 char *
 rbg_string_value_ptr(ptr)
@@ -148,8 +153,16 @@ void Init_glib2()
     Init_glib_spawn();
     Init_glib_fileutils();
     Init_glib_utils();
+
     Init_gobject();
 
+    /* Require GBoxed/GObject */
+    Init_glib_main_loop();
+    Init_glib_main_context();
+    Init_glib_source();
+    Init_glib_poll_fd();
+    Init_glib_io_channel();
+
     /* This is called here once. */
     G_DEF_SETTERS(mGLib);
 }
