@@ -17,12 +17,6 @@
  */
 
 #include "rbgp.h"
-#include <libgnomeprint/gnome-print-unit.h>
-#include <libgnomeprint/libgnomeprint-enum-types.h>
-
-#define RVAL2GPUB(obj) (RVAL2GFLAGS(obj, GNOME_TYPE_PRINT_PRINT_UNIT_BASE))
-#define GPUB2RVAL(obj) (GFLAGS2RVAL(obj, GNOME_TYPE_PRINT_PRINT_UNIT_BASE))
-
 
 static VALUE
 gp_unit_get_identity(VALUE self, VALUE base)
@@ -47,7 +41,7 @@ static VALUE
 gp_unit_get_by_name(VALUE self, VALUE name)
 {
   const GnomePrintUnit *unit;
-  unit = gnome_print_unit_get_by_name(RVAL2CSTR(name));
+  unit = gnome_print_unit_get_by_name((const guchar*)RVAL2CSTR(name));
 
   if (unit == NULL) {
     return Qnil;
@@ -60,7 +54,7 @@ static VALUE
 gp_unit_get_by_abbreviation(VALUE self, VALUE abbreviation)
 {
   const GnomePrintUnit *unit;
-  unit = gnome_print_unit_get_by_abbreviation(RVAL2CSTR(abbreviation));
+  unit = gnome_print_unit_get_by_abbreviation((const guchar*)RVAL2CSTR(abbreviation));
 
   if (unit == NULL) {
     return Qnil;
@@ -101,25 +95,25 @@ gp_unit_get_unittobase(VALUE self)
 static VALUE
 gp_unit_get_name(VALUE self)
 {
-  return CSTR2RVAL(RVAL2GPU(self)->name);
+  return CSTR2RVAL((const char*)RVAL2GPU(self)->name);
 }
 
 static VALUE
 gp_unit_get_abbr(VALUE self)
 {
-  return CSTR2RVAL(RVAL2GPU(self)->abbr);
+  return CSTR2RVAL((const char*)RVAL2GPU(self)->abbr);
 }
 
 static VALUE
 gp_unit_get_plural(VALUE self)
 {
-  return CSTR2RVAL(RVAL2GPU(self)->plural);
+  return CSTR2RVAL((const char*)RVAL2GPU(self)->plural);
 }
 
 static VALUE
 gp_unit_get_abbr_plural(VALUE self)
 {
-  return CSTR2RVAL(RVAL2GPU(self)->abbr_plural);
+  return CSTR2RVAL((const char*)RVAL2GPU(self)->abbr_plural);
 }
 
 
@@ -146,7 +140,7 @@ gp_convert_distance(VALUE self, VALUE distance, VALUE to)
 
 static VALUE
 gp_convert_distance_full(VALUE self, VALUE distance, VALUE to,
-                         VALUE ctmscale, VALUE devicescale)
+                         VALUE ctm_scale, VALUE device_scale)
 {
   gboolean ret;
   gdouble dist = NUM2DBL(distance);
@@ -155,8 +149,8 @@ gp_convert_distance_full(VALUE self, VALUE distance, VALUE to,
   ret = gnome_print_convert_distance_full(&dist,
                                           RVAL2GPU(self),
                                           RVAL2GPU(to),
-                                          NUM2DBL(ctmscale),
-                                          NUM2DBL(devicescale));
+                                          NUM2DBL(ctm_scale),
+                                          NUM2DBL(device_scale));
 
   if (ret) {
     result = rb_float_new(dist);
@@ -190,11 +184,13 @@ Init_gnome_print_unit(VALUE mGnome)
   
   cBase = G_DEF_CLASS(GNOME_TYPE_PRINT_PRINT_UNIT_BASE,
                       "PrintUnitBase", mGnome);
+
   G_DEF_CONSTANTS(cUnit, GNOME_TYPE_PRINT_PRINT_UNIT_BASE, "GNOME_PRINT_");
-
+ 
   rb_define_const(cUnit, "PS_UNIT", CONST_GPU2RVAL(GNOME_PRINT_PS_UNIT));
-
-  rb_define_const(cUnit, "UNIT_ALL",
+ 
+  rb_define_const(cUnit,
+                  "UNIT_ALL",
                   rb_funcall(cBase,
                              rb_intern("new"),
                              1,
