@@ -7,6 +7,8 @@ require "fileutils"
 maintainer = false
 
 def mkenums(output, config, files)
+  makefile_created = $makefile_created
+  $makefile_created = true
   args = []
   %w(fhead fprod ftail eprod vhead vprod vtail comments template).each do |param|
     param = param.intern
@@ -20,15 +22,18 @@ def mkenums(output, config, files)
     system('glib-mkenums', *args)
   end
   for_write.close
+  Process.waitpid(pid)
   File.open(output, "w") do |out|
     out.print(for_read.read)
   end
-  Process.waitpid(pid)
+ensure
+  $makefile_created = makefile_created
 end
 
-def mkenums_h(prefix, files)
+def mkenums_h(dir, prefix, files)
   header = prefix + ".h"
   const = "__#{header.upcase.gsub(/-|\./, '_')}__"
+  header = File.join(dir, header)
   config = {
     :fhead => <<-FHEAD,
 #ifndef #{const}
@@ -43,7 +48,7 @@ FHEAD
 FPROD
     :vhead => <<-VHEAD,
 GType @enum_name@_get_type (void);
-#define GNOME_TYPE_PRINTUI_@ENUMSHORT@ (@enum_name@_get_type())
+#define GNOME_TYPE_PRINT_@ENUMSHORT@ (@enum_name@_get_type())
 VHEAD
     :ftail => <<-FTAIL,
 G_END_DECLS
@@ -54,8 +59,8 @@ FTAIL
   mkenums(header, config, files)
 end
 
-def mkenums_c(prefix, files)
-  header = prefix + ".h"
+def mkenums_c(dir, prefix, files)
+  header = File.join(dir, prefix + ".h")
   c = prefix + ".c"
   config = {
     :fhead => <<-FHEAD,
@@ -103,27 +108,42 @@ PKGConfig.have_package("libgnomeprintui-2.2") or exit 1
 setup_win32(PACKAGE_NAME)
 
 add_depend_package("glib2", "glib/src", TOPDIR)
+add_depend_package("libart2", "libart/src", TOPDIR)
+add_depend_package("gnomeprint2", "gnomeprint/src", TOPDIR)
+
+have_header("libgnomeprintui/gnome-print-config-dialog.h")
 
 create_makefile_at_srcdir(PACKAGE_NAME, SRCDIR, "-DRUBY_GNOMEPRINTUI2_COMPILATION"){
+  enum_type_dir = "libgnomeprintui"
   enum_type_prefix = "libgnomeprintui-enum-types"
-  if !have_header("#{enum_type_prefix}.h")
+  unless have_header("#{enum_type_dir}/#{enum_type_prefix}.h")
+    FileUtils.mkdir_p(enum_type_dir)
+    enum_type_full_prefix = File.join(enum_type_dir, enum_type_prefix)
+    enum_type_c = "#{enum_type_prefix}.c"
+    enum_type_h = "#{enum_type_full_prefix}.h"
+    maintainer_enum_type_c = "#{enum_type_prefix}.c.maintainer"
+    maintainer_enum_type_h = "#{enum_type_prefix}.h.maintainer"
+    
     if maintainer
       include_paths = `pkg-config libgnomeprintui-2.2 --cflags-only-I`
       include_path = include_paths.split.find do |x|
         /libgnomeprintui/.match(x)
       end.sub(/^-I/, "")
       headers = Dir.glob(File.join(include_path, "libgnomeprintui", "*.h"))
-      mkenums_h(enum_type_prefix, headers)
-      mkenums_c(enum_type_prefix, headers)
-    else
-      %w(h c).each do |ext|
-        enum_type_filename = "#{enum_type_prefix}.#{ext}"
-        FileUtils.cp("#{enum_type_filename}.maintainer", enum_type_filename)
-      end
-    end
-  end
 
-  add_distcleanfile(enum_type_prefix + ".c")
-  add_distcleanfile(enum_type_prefix + ".h")
+      mkenums_c(enum_type_dir, enum_type_prefix, headers)
+      mkenums_h(enum_type_dir, enum_type_prefix, headers)
+
+      FileUtils.mv("#{enum_type_prefix}.c", maintainer_enum_type_c)
+      FileUtils.mv("#{File.join(enum_type_dir, enum_type_prefix)}.h",
+                   maintainer_enum_type_h)
+    end
+
+    FileUtils.cp(maintainer_enum_type_c, enum_type_c)
+    FileUtils.cp(maintainer_enum_type_h, enum_type_h)
+
+    add_distcleanfile(enum_type_c)
+    add_distcleanfile(enum_type_h)
+  end
 }
 create_top_makefile
