@@ -26,7 +26,7 @@ static VALUE
 gpui_job_preview_new(VALUE self, VALUE job, VALUE title)
 {
   G_INITIALIZE(self, gnome_print_job_preview_new(RVAL2GOBJ(job),
-                                                 RVAL2CSTR(title)));
+                                                 (const guchar*)RVAL2CSTR(title)));
   /* XXX: Is it good way??? */
   g_object_ref(_SELF(self));
   return Qnil;
