@@ -127,6 +127,10 @@ VALUE instanciate_pluginfeature (GstPluginFeature * feature);
 /* implemented in rbgststructure.c */
 VALUE gst_structure_to_ruby_hash (GstStructure *gst_struct);
 GstStructure *ruby_hash_to_gst_structure (VALUE hash);
+GstStructure *ruby_hash_to_gst_structure_with_name (VALUE hash,
+                                                    const char *name);
+
+#define GST_TAG_LIST_STRUCTURE_NAME   "taglist"
 
 #define DBL2NUM(v)      (rb_float_new(v))
 
