@@ -1,17 +1,18 @@
-#!/usr/local/bin/ruby
+#!/usr/bin/env ruby
 =begin
   label.rb - Ruby/GTK sample script.
 
-  Copyright (c) 2002-2004 Ruby-GNOME2 Project Team
+  Copyright (c) 2002-2005 Ruby-GNOME2 Project Team
   This program is licenced under the same licence as Ruby-GNOME2.
 
-  $Id: label.rb,v 1.5 2004/03/05 16:24:30 mutoh Exp $
+  $Id: label.rb,v 1.7 2005/07/14 17:01:49 mutoh Exp $
 =end
 
 require 'gtk2'
 
 Gtk.init
 win = Gtk::Window.new
+win.signal_connect("destroy"){Gtk.main_quit}
 label1 = Gtk::Label.new("_Not Use Mnemonic")
 label1.selectable = true
 label2 = Gtk::Label.new("_Use Mnemonic", true)
