@@ -1,11 +1,11 @@
-#!/usr/local/bin/ruby
+#!/usr/bin/env ruby
 =begin
   radiobutton.rb - Ruby/GTK sample script.
 
-  Copyright (c) 2002,2003 Ruby-GNOME2 Project Team 
+  Copyright (c) 2002-2005 Ruby-GNOME2 Project Team 
   This program is licenced under the same licence as Ruby-GNOME2.
 
-  $Id: radiobutton.rb,v 1.7 2003/04/01 16:26:34 mutoh Exp $
+  $Id: radiobutton.rb,v 1.9 2005/07/14 17:01:49 mutoh Exp $
 =end
 
 require 'gtk2'
@@ -14,35 +14,36 @@ Gtk.init
 
 window = Gtk::Window.new
 window.set_title("radio buttons")
-window.set_border_width(0)
 
-box1 = Gtk::VBox.new(false, 0)
+box1 = Gtk::VBox.new
 window.add(box1)
 
 box2 = Gtk::VBox.new(false, 10)
-box2.set_border_width 10
-box1.pack_start(box2, true, true, 0)
+box2.border_width = 10
+box1.add(box2)
 
 button1 = Gtk::RadioButton.new("_button1")
 button2 = Gtk::RadioButton.new(button1, "_button2", false)
 button3 = Gtk::RadioButton.new(button1, Gtk::Stock::QUIT)
+
 box2.add(button1).add(button2).add(button3)
 
-separator = Gtk::HSeparator.new
-box1.pack_start(separator, false, true, 0)
+box1.add(Gtk::HSeparator.new)
 
 box2 = Gtk::VBox.new(false, 10)
-box2.set_border_width(10)
-box1.pack_start(box2, false, true, 0)
+box2.border_width = 10
+box1.add(box2)
 
 close = Gtk::Button.new("close")
 close.signal_connect("clicked") do
-	Gtk.main_quit
+  Gtk.main_quit
 end
-box2.pack_start(close, true, true, 0)
-close.set_flags(Gtk::Widget::CAN_DEFAULT)
+box2.add(close)
+
+close.can_default = true
 close.grab_default
 
+window.signal_connect("destroy"){Gtk.main_quit}
 window.show_all
 
 Gtk.main
