@@ -4,7 +4,7 @@
   rbgdkpango.c -
 
   $Author: mutoh $
-  $Date: 2005/01/30 11:24:36 $
+  $Date: 2005/05/27 18:33:33 $
 
   Copyright (C) 2003,2004 Masao Mutoh
 ************************************************/
@@ -50,6 +50,13 @@ gdkpango_attr_embossed_initialize(self, embossed)
     return Qnil;
 }
 
+static VALUE
+gdkpango_attr_embossed_value(self)
+    VALUE self;
+{
+    return CBOOL2RVAL(((GdkPangoAttrEmbossed*)RVAL2ATTR(self))->embossed);
+}
+
 static VALUE
 gdkpango_attr_stipple_initialize(self, stipple)
     VALUE self, stipple;
@@ -123,6 +130,7 @@ Init_gtk_gdk_pango()
     klass = rb_define_class_under(mGdk, "PangoAttrEmbossed", pattrbool);
     rb_define_method(klass, "initialize", gdkpango_attr_embossed_initialize, 1);
     tmpattr = gdk_pango_attr_embossed_new(TRUE);
+    rb_define_method(klass, "value", gdkpango_attr_embossed_value, 0);
     RBPANGO_ADD_ATTRIBUTE(tmpattr->klass->type, klass);
 
     klass = rb_define_class_under(mGdk, "PangoAttrStipple", pattr);
