@@ -4,7 +4,7 @@
   rbgtkcontainer.c -
 
   $Author: mutoh $
-  $Date: 2004/08/22 13:30:40 $
+  $Date: 2005/07/22 18:07:18 $
 
   Copyright (C) 2002-2004 Ruby-GNOME2 Project Team
   Copyright (C) 1998-2000 Yukihiro Matsumoto,
@@ -460,7 +460,7 @@ cont_s_child_properties(argc, argv, self)
     VALUE self;
 {
     GObjectClass* oclass = g_type_class_ref(CLASS2GTYPE(self));
-    gint n_properties;
+    guint n_properties;
     GParamSpec** props;
     VALUE inherited_too;
     VALUE ary;
