@@ -4,9 +4,9 @@
   rbgtkdialog.c -
 
   $Author: mutoh $
-  $Date: 2005/01/24 16:47:18 $
+  $Date: 2005/07/17 16:55:27 $
 
-  Copyright (C) 2002-2004 Ruby-GNOME2 Project Team
+  Copyright (C) 2002-2005 Ruby-GNOME2 Project Team
   Copyright (C) 1998-2000 Yukihiro Matsumoto,
                           Daisuke Kanda,
                           Hiroshi Igarashi
@@ -16,12 +16,6 @@
 
 #define _SELF(self) (GTK_DIALOG(RVAL2GOBJ(self)))
 
-/*
- * 2003/08/31 Masao
- * We don't use RVAL2GENUM/GENUM2RVAL for GtkResponseType.
- * Because sometimes you may use your own number as response_id.
- */
-
 static ID id_to_a;
 
 static VALUE
@@ -77,7 +71,7 @@ dialog_initialize(argc, argv, self)
 
     if (argc == 0){
         RBGTK_INITIALIZE(self, gtk_dialog_new());
-    } else if (argc > 3){
+    } else if (argc > 0){
         GtkDialog* dialog = GTK_DIALOG(g_object_new(GTK_TYPE_DIALOG, NULL));
         GtkDialogFlags gflags = NIL_P(flags) ? 0 : RVAL2GFLAGS(flags, GTK_TYPE_DIALOG_FLAGS);
         if (! NIL_P(title))
@@ -93,7 +87,8 @@ dialog_initialize(argc, argv, self)
             gtk_dialog_set_has_separator(dialog, FALSE);
 
         RBGTK_INITIALIZE(self, dialog);
-        rbgtk_dialog_add_buttons_internal(self, button_ary);
+        if (! NIL_P(button_ary))
+            rbgtk_dialog_add_buttons_internal(self, button_ary);
     } else {
         rb_raise(rb_eArgError, "invalid argument number");
     }
