@@ -12,7 +12,7 @@ $LOAD_PATH.unshift MKMF_GNOME2_DIR
 
 require 'mkmf-gnome2'
 
-PKGConfig.have_package('libpanelapplet-2.0') or exit 1
+PKGConfig.have_package('libpanelapplet-2.0', 2, 6) or exit 1
 setup_win32(PACKAGE_NAME)
 
 add_depend_package("glib2", "glib/src", TOPDIR)
