@@ -21,9 +21,13 @@
 #include <rbglib.h>
 #include <rbgobject.h>
 
-#include <librsvg/rsvg-gz.h>
+#ifdef HAVE_LIBRSVG_RSVG_GZ_H
+#  include <librsvg/rsvg-gz.h>
+#else
+#  include <librsvg/rsvg.h>
+#endif
 
-#ifdef HAVE_LIBRSVG_ENUM_TYPES_H
+#ifdef HAVE_LIBRSVG_LIBRSVG_ENUM_TYPES_H
 #  include <librsvg/librsvg-enum-types.h>
 #else
 #  include "librsvg-enum-types.h"
@@ -87,7 +91,12 @@ rb_rsvg_handle_new(int argc, VALUE *argv, VALUE klass)
   rb_scan_args(argc, argv, "01", &gz);
 
   if (RTEST(gz)) {
+#ifdef HAVE_LIBRSVG_RSVG_GZ_H
     handle = rsvg_handle_new_gz();
+#else
+    rb_warning("gz handling is not supported in your librsvg");
+    handle = rsvg_handle_new();
+#endif
   } else {
     handle = rsvg_handle_new();
   }
@@ -123,7 +132,7 @@ rb_rsvg_handle_write(VALUE self, VALUE buf)
   gboolean result;
   GError *error = NULL;
 
-  result = rsvg_handle_write(_SELF(self), RVAL2CSTR(buf),
+  result = rsvg_handle_write(_SELF(self), (const guchar*)RVAL2CSTR(buf),
                              RSTRING(buf)->len, &error);
 
   if (!result) RAISE_GERROR(error);
@@ -412,15 +421,15 @@ Init_rsvg2(void) {
 
 /* Extended Convenience API */
 
-  rb_define_method(cHandle, "pixbuf_from_file_at_size_ex",
+  rb_define_method(cHandle, "pixbuf_from_file_at_size",
                    rb_rsvg_pixbuf_from_file_at_size_ex, 3);
-  rb_define_method(cHandle, "pixbuf_from_file_ex",
+  rb_define_method(cHandle, "pixbuf_from_file",
                    rb_rsvg_pixbuf_from_file_ex, 1);
-  rb_define_method(cHandle, "pixbuf_from_file_at_zoom_ex",
+  rb_define_method(cHandle, "pixbuf_from_file_at_zoom",
                    rb_rsvg_pixbuf_from_file_at_zoom_ex, 3);
-  rb_define_method(cHandle, "pixbuf_from_file_at_max_size_ex",
+  rb_define_method(cHandle, "pixbuf_from_file_at_max_size",
                    rb_rsvg_pixbuf_from_file_at_max_size_ex, 3);
-  rb_define_method(cHandle, "pixbuf_from_file_at_zoom_with_max_ex",
+  rb_define_method(cHandle, "pixbuf_from_file_at_zoom_with_max",
                    rb_rsvg_pixbuf_from_file_at_zoom_with_max_ex, 5);
   
   G_DEF_SETTERS(cHandle);
